@@ -1,18 +1,20 @@
 # -*- coding: UTF-8 -*-
 import os
 import json
-import sys
-from twisted.internet.protocol import Factory, Protocol
 from twisted.internet import reactor, ssl
 from twisted.application import internet, service
 from twisted.web import server, wsgi, static
 from twisted.python import threadpool, log
-from autobahn.twisted.websocket import WebSocketServerProtocol, WebSocketServerFactory
+from autobahn.twisted.websocket import WebSocketServerFactory
 from autobahn.twisted.resource import WebSocketResource
 from OpenSSL import SSL
-
+import lisa
 import pkg_resources
-configuration = json.load(open(pkg_resources.resource_filename(__name__, 'configuration/lisa.json.sample')))
+
+if not os.path.exists('/etc/lisa/server/lisa.json'):
+    configuration = json.load(open(pkg_resources.resource_filename(__name__, 'configuration/lisa.json.sample')))
+else:
+    configuration = json.load(open('/etc/lisa/server/lisa.json'))
 path = os.path.abspath(__file__)
 dir_path = os.path.dirname(path)
 
@@ -41,18 +43,6 @@ def makeService(config):
     if config['configuration']:
         configuration = json.load(open(config['configuration']))
 
-    # Check if plugin directory exists. If not, create it
-    try:
-        if not os.path.exists(os.path.normpath(config['plugins'])):
-            os.makedirs(os.path.normpath(config['plugins']))
-        if not os.path.exists(os.path.normpath(config['plugins'] + '/__init__.py')):
-            open(os.path.normpath(config['plugins'] + '/__init__.py'), 'w').close()
-    except:
-        log.err("Directory %s doesn't exist, and it seems impossible to create it" % config['plugins'])
-        pass
-    sys.path.append(os.path.normpath(config['plugins']))
-    configuration['plugins'] = config['plugins']
-
     from lisa.server import libs
 
     # Creating MultiService
